==> django_pyhub_rag-1.2.0-py3-none-any.whl: pyhub/web/settings.py <==
from pathlib import Path

from environ import Env

from pyhub import load_envs, load_toml, make_settings

BASE_DIR = Path(__file__).resolve().parent


env = Env()

toml_path = env.str("TOML_PATH", default=None)
if toml_path:
    load_toml(toml_path)

env_path = env.str("ENV_PATH", default=None)
if env_path:
    load_envs(env_path)


PYHUB_SETTINGS = make_settings(
    base_dir=BASE_DIR,
    debug_default_value=True,
)


ROOT_URLCONF = "urls"
WSGI_APPLICATION = "wsgi.application"
ASGI_APPLICATION = "asgi.application"

DEBUG = PYHUB_SETTINGS.DEBUG
SECRET_KEY = PYHUB_SETTINGS.SECRET_KEY

INTERNAL_IPS = PYHUB_SETTINGS.INTERNAL_IPS
ALLOWED_HOSTS = PYHUB_SETTINGS.ALLOWED_HOSTS
CSRF_TRUSTED_ORIGINS = PYHUB_SETTINGS.CSRF_TRUSTED_ORIGINS

INSTALLED_APPS = [
    *PYHUB_SETTINGS.INSTALLED_APPS,
    "django.contrib.admin",
    "django.contrib.admindocs",
    "accounts",
]

MIDDLEWARE = PYHUB_SETTINGS.MIDDLEWARE

TEMPLATES = PYHUB_SETTINGS.TEMPLATES

DATABASE_ROUTERS = PYHUB_SETTINGS.DATABASE_ROUTERS
DATABASES = PYHUB_SETTINGS.DATABASES

AUTH_USER_MODEL = PYHUB_SETTINGS.AUTH_USER_MODEL
AUTH_PASSWORD_VALIDATORS = PYHUB_SETTINGS.AUTH_PASSWORD_VALIDATORS

CACHES = PYHUB_SETTINGS.CACHES

LOGGING = PYHUB_SETTINGS.LOGGING

LANGUAGE_CODE = PYHUB_SETTINGS.LANGUAGE_CODE
TIME_ZONE = PYHUB_SETTINGS.TIME_ZONE

USE_I18N = PYHUB_SETTINGS.USE_I18N
USE_TZ = PYHUB_SETTINGS.USE_TZ
USER_DEFAULT_TIME_ZONE = PYHUB_SETTINGS.USER_DEFAULT_TIME_ZONE

STATIC_URL = PYHUB_SETTINGS.STATIC_URL
STATIC_ROOT = PYHUB_SETTINGS.STATIC_ROOT  # noqa
STATICFILES_DIRS = PYHUB_SETTINGS.STATICFILES_DIRS
STATICFILES_FINDERS = PYHUB_SETTINGS.STATICFILES_FINDERS

MEDIA_URL = PYHUB_SETTINGS.MEDIA_URL
MEDIA_ROOT = PYHUB_SETTINGS.MEDIA_ROOT

DEFAULT_AUTO_FIELD = PYHUB_SETTINGS.DEFAULT_AUTO_FIELD

#
# api
#

SERVICE_DOMAIN = PYHUB_SETTINGS.SERVICE_DOMAIN

NCP_MAP_CLIENT_ID = PYHUB_SETTINGS.NCP_MAP_CLIENT_ID
NCP_MAP_CLIENT_SECRET = PYHUB_SETTINGS.NCP_MAP_CLIENT_SECRET

PROMPT_TEMPLATES = PYHUB_SETTINGS.PROMPT_TEMPLATES

CRISPY_ALLOWED_TEMPLATE_PACKS = PYHUB_SETTINGS.CRISPY_ALLOWED_TEMPLATE_PACKS
CRISPY_TEMPLATE_PACK = PYHUB_SETTINGS.CRISPY_TEMPLATE_PACK

ENABLE_MAP_SERVICE = env.bool("ENABLE_MAP_SERVICE", default=False)

UPSTAGE_API_KEY = env.str("UPSTAGE_API_KEY", default=None)
OPENAI_API_KEY = env.str("OPENAI_API_KEY", default=None)
ANTHROPIC_API_KEY = env.str("ANTHROPIC_API_KEY", default=None)
GOOGLE_API_KEY = env.str("GOOGLE_API_KEY", default=None)


# django-components

COMPONENTS = PYHUB_SETTINGS.COMPONENTS

==> django_pyhub_rag-1.2.1-py3-none-any.whl: pyhub/web/settings.py <==
from pathlib import Path

from environ import Env

from pyhub import load_envs, load_toml, make_settings

BASE_DIR = Path(__file__).resolve().parent


env = Env()

toml_path = env.str("TOML_PATH", default=None)
if toml_path:
    load_toml(toml_path)

env_path = env.str("ENV_PATH", default=None)
if env_path:
    load_envs(env_path)


PYHUB_SETTINGS = make_settings(
    base_dir=BASE_DIR,
    debug_default_value=True,
    additional_apps=[
        "django.contrib.admin",
        "django.contrib.admindocs",
        "accounts",
    ]
)


ROOT_URLCONF = "urls"
WSGI_APPLICATION = "wsgi.application"
ASGI_APPLICATION = "asgi.application"

DEBUG = PYHUB_SETTINGS.DEBUG
SECRET_KEY = PYHUB_SETTINGS.SECRET_KEY

INTERNAL_IPS = PYHUB_SETTINGS.INTERNAL_IPS
ALLOWED_HOSTS = PYHUB_SETTINGS.ALLOWED_HOSTS
CSRF_TRUSTED_ORIGINS = PYHUB_SETTINGS.CSRF_TRUSTED_ORIGINS

INSTALLED_APPS = PYHUB_SETTINGS.INSTALLED_APPS

MIDDLEWARE = PYHUB_SETTINGS.MIDDLEWARE

TEMPLATES = PYHUB_SETTINGS.TEMPLATES

DATABASE_ROUTERS = PYHUB_SETTINGS.DATABASE_ROUTERS
DATABASES = PYHUB_SETTINGS.DATABASES

AUTH_USER_MODEL = "accounts.User"  # PYHUB_SETTINGS.AUTH_USER_MODEL
AUTH_PASSWORD_VALIDATORS = PYHUB_SETTINGS.AUTH_PASSWORD_VALIDATORS

CACHES = PYHUB_SETTINGS.CACHES

LOGGING = PYHUB_SETTINGS.LOGGING

LANGUAGE_CODE = PYHUB_SETTINGS.LANGUAGE_CODE
TIME_ZONE = PYHUB_SETTINGS.TIME_ZONE

USE_I18N = PYHUB_SETTINGS.USE_I18N
USE_TZ = PYHUB_SETTINGS.USE_TZ
USER_DEFAULT_TIME_ZONE = PYHUB_SETTINGS.USER_DEFAULT_TIME_ZONE

STATIC_URL = PYHUB_SETTINGS.STATIC_URL
STATIC_ROOT = PYHUB_SETTINGS.STATIC_ROOT  # noqa
STATICFILES_DIRS = PYHUB_SETTINGS.STATICFILES_DIRS
STATICFILES_FINDERS = PYHUB_SETTINGS.STATICFILES_FINDERS

MEDIA_URL = PYHUB_SETTINGS.MEDIA_URL
MEDIA_ROOT = PYHUB_SETTINGS.MEDIA_ROOT

DEFAULT_AUTO_FIELD = PYHUB_SETTINGS.DEFAULT_AUTO_FIELD

#
# api
#

SERVICE_DOMAIN = PYHUB_SETTINGS.SERVICE_DOMAIN

NCP_MAP_CLIENT_ID = PYHUB_SETTINGS.NCP_MAP_CLIENT_ID
NCP_MAP_CLIENT_SECRET = PYHUB_SETTINGS.NCP_MAP_CLIENT_SECRET

PROMPT_TEMPLATES = PYHUB_SETTINGS.PROMPT_TEMPLATES

CRISPY_ALLOWED_TEMPLATE_PACKS = PYHUB_SETTINGS.CRISPY_ALLOWED_TEMPLATE_PACKS
CRISPY_TEMPLATE_PACK = PYHUB_SETTINGS.CRISPY_TEMPLATE_PACK

ENABLE_MAP_SERVICE = env.bool("ENABLE_MAP_SERVICE", default=False)

UPSTAGE_API_KEY = env.str("UPSTAGE_API_KEY", default=None)
OPENAI_API_KEY = env.str("OPENAI_API_KEY", default=None)
ANTHROPIC_API_KEY = env.str("ANTHROPIC_API_KEY", default=None)
GOOGLE_API_KEY = env.str("GOOGLE_API_KEY", default=None)


# django-components

COMPONENTS = PYHUB_SETTINGS.COMPONENTS
